# BEAKER

[![Build Status](https://travis-ci.com/jguhlin/beaker.svg?branch=main)](https://travis-ci.com/jguhlin/beaker) [![codecov](https://codecov.io/gh/jguhlin/beaker/branch/main/graph/badge.svg?token=C83YL05H8H)](undefined)

Implementation of BEAKER Machine Learning Model by [Joseph Guhlin](https://github.com/jguhlin) and [Rachael Ashby](https://github.com/r-ashby).

More info coming soon

# Code Format
We use python black code formatter for this repo.

